summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lib/mixlib/shellout/unix.rb2
1 files changed, 1 insertions, 1 deletions
diff --git a/lib/mixlib/shellout/unix.rb b/lib/mixlib/shellout/unix.rb
index 3172f6e..e0b6d67 100644
--- a/lib/mixlib/shellout/unix.rb
+++ b/lib/mixlib/shellout/unix.rb
@@ -322,7 +322,7 @@ module Mixlib
attempt_buffer_read
e = Marshal.load(@process_status)
raise(Exception === e ? e : "unknown failure: #{e.inspect}")
- rescue EOFError # If we get an EOF error, then the exec was successful
+ rescue ArgumentError # If we get an ArgumentError error, then the exec was successful
true
ensure
child_process_status.close